@@ -26,30 +26,30 @@
 //! // Writing simple
 //! let mut src_map1 = HashMap::new();
 //! src_map1.insert("a".to_string(), "b".to_string());
-//! let mut f = try!(File::create(&file_name));
-//! try!(write(BufWriter::new(f), &src_map1));
+//! let mut f = File::create(&file_name)?;
+//! write(BufWriter::new(f), &src_map1)?;
 //!
 //! // Writing advanced
 //! let mut src_map2 = HashMap::new();
 //! src_map2.insert("a".to_string(), "b".to_string());
-//! let mut f = try!(File::create(&file_name));
+//! let mut f = File::create(&file_name)?;
 //! let mut writer = PropertiesWriter::new(BufWriter::new(f));
 //! for (k, v) in src_map2.iter() {
-//!   try!(writer.write(&k, &v));
+//!   writer.write(&k, &v)?;
 //! }
 //! writer.flush();
 //!
 //! // Reading simple
-//! let mut f2 = try!(File::open(&file_name));
-//! let dst_map1 = try!(read(BufReader::new(f2)));
+//! let mut f2 = File::open(&file_name)?;
+//! let dst_map1 = read(BufReader::new(f2))?;
 //! assert_eq!(src_map1, dst_map1);
 //!
 //! // Reading advanced
-//! let mut f = try!(File::open(&file_name));
+//! let mut f = File::open(&file_name)?;
 //! let mut dst_map2 = HashMap::new();
-//! try!(PropertiesIter::new(BufReader::new(f)).read_into(|k, v| {
+//! PropertiesIter::new(BufReader::new(f)).read_into(|k, v| {
 //!   dst_map2.insert(k, v);
-//! }));
+//! })?;
 //! assert_eq!(src_map2, dst_map2);
 //! # Ok(())
 //! # }
@@ -435,6 +435,7 @@ impl LineParser {
         [\x23!] # start of comment (# or !)
         [\x20\t\r\n\x0c]* # ignorable whitespace
         (.*?) # comment text
+        [\x20\t\r\n\x0c]* # ignorable whitespace
       |
         (
           (?:[^\\:=\x20\t\r\n\x0c]|\\.)* # key
@@ -452,7 +453,6 @@ impl LineParser {
           )
         )?
       )
-      [\x20\t\r\n\x0c]* # ignorable whitespace
       $
     ";
     LineParser {
@@ -888,7 +888,7 @@ mod tests {
       ("a = b", Some(ParsedLine::KVPair("a", "b"))),
       ("a : b", Some(ParsedLine::KVPair("a", "b"))),
       ("a b", Some(ParsedLine::KVPair("a", "b"))),
-      (" a = b", Some(ParsedLine::KVPair("a", "b"))),
+      (" a = b ", Some(ParsedLine::KVPair("a", "b "))),
       (" a : b", Some(ParsedLine::KVPair("a", "b"))),
       (" a b", Some(ParsedLine::KVPair("a", "b"))),
       ("a:=b", Some(ParsedLine::KVPair("a", "=b"))),
@@ -899,6 +899,9 @@ mod tests {
       ("a\\\\ \\\\:\\\\=b c", Some(ParsedLine::KVPair("a\\\\", "\\\\:\\\\=b c"))),
       ("\\  b", Some(ParsedLine::KVPair("\\ ", "b"))),
       ("=", Some(ParsedLine::KVPair("", ""))),
+      ("=x", Some(ParsedLine::KVPair("", "x"))),
+      ("x=", Some(ParsedLine::KVPair("x", ""))),
+      ("\\=x", Some(ParsedLine::KVPair("\\=x", ""))),
       ("\u{1F41E}=\u{1F41E}", Some(ParsedLine::KVPair("\u{1F41E}", "\u{1F41E}"))),
     ];
     let splitter = super::LineParser::new();
@@ -960,7 +963,8 @@ mod tests {
         mk_pair(7, "i", "j#comment3"),
         mk_comment(10, "comment4"),
       ]),
-      ("a = b\\\n  c, d ", vec![mk_pair(1, "a", "bc, d")]),
+      ("a = b\\\n  c, d ", vec![mk_pair(1, "a", "bc, d ")]),
+      ("x=\\\\\\\nty", vec![mk_pair(1, "x", "\\ty")]),
     ]),
     (UTF_8 as &Encoding,
     vec![
